==> ath1121501_1.8.2.tar.gz: ath1121501/man/ath1121501PATH2PROBE.Rd <==
\name{ath1121501PATH2PROBE}
\alias{ath1121501PATH2PROBE}
\title{Map between Kyoto Encyclopedia of Genes and Genomes (KEGG)
  pathway identifiers and Manufacturer Identifiers}
\description{
 ath1121501PATH2PROBE is an R environment that provides mappings between
 KEGG ids and manufacturer ids.
}
\details{
  Each KEGG id is mapped to a named vector of manufacturer ids. The name
  represents the KEGG id and the vector contains all manufacturer ids
  that are found in that particular pathway. An \code{NA} is reported
  for any KEGG id that cannot be mapped to any manufacturer ids.

  Pathway name for a given pathway id can be obtained using the KEGG
  data package that can either be built using AnnBuilder or downloaded
  from Bioconductor \url{http://www.bioconductor.org}.

  Graphic presentations of pathways are searchable at
  \url{http://www.genome.ad.jp/kegg/pathway.html} using pathway ids as keys.
  
  Mappings were based on data provided by:

  Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Pathways/aracyc_dump_20050412}
Built: N/A

  Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Genes/gene_aliases.20041105}
Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Genes/TAIR_sequenced_genes}
Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Genes/Gene_Anatomy/ATH_Anatomy.20040209.txt}
Built: N/A

  Package built Tue May 17 18:45:34 2005
}
\references{
\url{http://www.genome.ad.jp/kegg/}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(ath1121501PATH2PROBE)
    # Remove pathway ids that do not map to any probe id
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
        # The probe ids for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
    } 
}

\keyword{datasets}

==> ath1121501_1.10.0.tar.gz: ath1121501/man/ath1121501PATH2PROBE.Rd <==
\name{ath1121501PATH2PROBE}
\alias{ath1121501PATH2PROBE}
\title{Map between Kyoto Encyclopedia of Genes and Genomes (KEGG)
  pathway identifiers and Manufacturer Identifiers}
\description{
 ath1121501PATH2PROBE is an R environment that provides mappings between
 KEGG ids and manufacturer ids.
}
\details{
  Each KEGG id is mapped to a named vector of manufacturer ids. The name
  represents the KEGG id and the vector contains all manufacturer ids
  that are found in that particular pathway. An \code{NA} is reported
  for any KEGG id that cannot be mapped to any manufacturer ids.

  Pathway name for a given pathway id can be obtained using the KEGG
  data package that can either be built using AnnBuilder or downloaded
  from Bioconductor \url{http://www.bioconductor.org}.

  Graphic presentations of pathways are searchable at
  \url{http://www.genome.ad.jp/kegg/pathway.html} using pathway ids as keys.
  
  Mappings were based on data provided by:

  Tair: \url{http://gopher5/compbio/annotationSourceData/ftp.arabidopsis.org/home/tair/Pathways/aracyc_dump_20050412}
Built: N/A

  Tair: \url{http://gopher5/compbio/annotationSourceData/ftp.arabidopsis.org/home/tair/Genes/gene_aliases.20041105}
Tair: \url{http://gopher5/compbio/annotationSourceData/ftp.arabidopsis.org/home/tair/Genes/TAIR_sequenced_genes}
Tair: \url{http://gopher5/compbio/annotationSourceData/ftp.arabidopsis.org/home/tair/Ontologies/TAIR_Ontology/ATH_anatomy.20050119.txt}
Built: N/A

  Package built Tue Oct  4 19:05:27 2005
}
\references{
\url{http://www.genome.ad.jp/kegg/}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(ath1121501PATH2PROBE)
    # Remove pathway ids that do not map to any probe id
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
        # The probe ids for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
    } 
}

\keyword{datasets}
